################################################
# Function: buildExpaFileFromModelorg
#
# 
#


buildExpaFileFromModelorg <- function(model,
                                      filename = "model.expa",
                                      filepath = ".") {
	
    if (!is(model, "modelorg")) {
        stop("needs an object of class modelorg!")
    }
	
    tofile <- file.path(filepath, filename)
    
    return(tofile)
	#first part of the ExPa-File starts with this:
	cat("(Internal Fluxes)\n", file=file, append=FALSE)
	
	for(j in (1:dim(S(model))[2]) ){
		
		# save an I for irreversible reaction a R for reversible
		if(react_rev(model)[j]){
			typ <- "R"
		}else{
			typ <- "I"
		}
		
		# write the beginning of the line for this reaction in the file. looks like this:
		# ACKr        R
		cat(react_id(model)[j], "\t\t\t", typ, " ", file=file, append=TRUE, sep="")
		
		# add for every metabolite in this reaction an entry in this line like this: +2 actp[c]
		for(i in which(S(model)[,j]!=0)){
			v <- S(model)[i,j]
			
			c <- ""
			# when the entry in S is positive we have to add a '+' to the factor v
			if(v > 0) c <- "+"
			
			# concatenate sign, factor, name of the metabolite
			cat(c, v, " ", met_id(model)[i], " ", file=file, append=TRUE, sep="")
		}
		# final newline
		cat("\n", file=file, append=TRUE)
	}
	
	# second part of the ExPa file starts like this
	cat("(Exchange Fluxes)\n", file=file, append=TRUE)

	# quick and dirty: look in met_id for "[e]". these are the exchange fluxes
	# all fluxes can be marked as "Free", because the direction is definied 
	# by a successive reaction
	for(i in grep("[e]", met_id(model), value=TRUE)){
		# lines have to look like this: ac[e] Free
		cat(i, " Free\n", file=file, append=TRUE, sep="")
	}
	
}

