\name{buildCytoscapeNAFiles}
\alias{buildCytoscapeNAFiles}
\title{
makes a node attribute file for cytoscape
}
\description{
With a given \code{list} of reaction sets this function builds two node attribute files for cytoscape. One file will highlight every reaction set in an own color (up to 216 colors) and the other file will set the opacity of every node to 255. If blocked reactions are given, they will be colored red (255, 0, 0).
}
\usage{
buildCytoscapeNAFiles(model = NULL, 
		reactSets = NULL, blocked = NULL, fileprefix = NULL)
}
\arguments{
  \item{model}{
	a valid \code{modelorg} object. this should be created from the SBML-file, which is loaded in cytoscape.
}
  \item{reactSets}{
	a \code{list} with the reactionsets to color.
}
  \item{blocked}{
  	a integer vector containing blocked reactions. if blocked reactions should not be highlighted set it as NULL.
}
  \item{fileprefix}{
	the two files will be named like this: <fileprefix>_fillColor.NA and <fileprefix>_opacity.NA
}
}
\value{
	This function will create 2 files:\cr
	<fileprefix>_fillColor.NA\cr
	<fileprefix>_opacity.NA
}
\references{
http://www.cytoscape.org/

see also \code{\link{sybilFCF}}
}
\author{
Claus Jonathan Fritzemeier \email{clausjonathan.fritzemeier@uni-duesseldorf.de}
}
\seealso{
	functions to create a \code{list} as input for this function:\cr
	\code{\link{orderDirectedReactionSets}}\cr
	\code{\link{orderSymmetricReactionSets}}
}
\examples{
	data("Ec_core")
	res <- fcf(Ec_core, setObjectiveReactionToZero=TRUE)
	
	rS <- orderSymmetricReactionSets(res$A, TRUE)

	buildCytoscapeNAFiles(model = Ec_core, reactSets = rS,
			blocked = res$reactions$blocked, fileprefix = "ecoli_core")
	
	# now load the SBML file of the network in cytoscape
	#					and add the two node attribute files
}
\keyword{cytoscape}
