\name{sybilFCF-package}
\alias{sybilFCF-package}
\alias{sybilFCF}
\docType{package}
\title{
flux Coupling finder extention for SyBiL
}
\description{
This package adds the possibility of finding flux couplings, calculating extreme pathways and identifying reactiontypes in metabolic networks as an extention to SyBiL. It uses A. Bockmayr's and A. Larhlimi's MMBFCF for the flux coupling finder and rcdd for the double description method.
}
\details{
\tabular{ll}{
Package: \tab sybilFCF\cr
Type: \tab Package\cr
Version: \tab 0.2\cr
Date: \tab 2010-02-15\cr
License: \tab Free\cr
}
This package is designed to find flux couplings in metabolic network. It follows the approach as described from A. Bockmayr and A. Larhlimi in "A New Approach to Flux Coupling Analysis of Metabolic Networks".


sybilFCF uses \code{modelorg} objects for input.\cr

\code{ec <- readSBML("Ec_core_flux1.xml")}\cr

then we have to calculate a set of generating vectors of the flux cone using \code{rcdd}:\cr

\code{gv <- calcGeneratingVectorsFromModelorg(ec, setObjectiveReactionToZero=TRUE)}\cr

with this set of generating vectors we can find the couplings:

\code{ res <- fcf(ec, gv) }

if you are only interested in the couplings, you can just do this too:

\code{ res <- fcf(ec) }

Now \code{res} includes following data:\cr
\code{res\$reactions} the reactiontypes,

and flux coupling types in 3 matrices:\cr

\code{res\$A} contains coupling type 1: \eqn{i \stackrel{\lambda}\sim j}\cr
\code{res\$B} contains coupling type 2: \eqn{i \stackrel{=0}\rightarrow j}\cr
\code{res\$C} contains coupling type 3: \eqn{i \stackrel{=0}\leftrightarrow j}\cr

Now summarize the pairs \eqn{(i, j)} to greater sets:\cr

\code{rS <- orderSymmetricReactionSets(erg$A, sortSets=TRUE)}\cr

In the end lets create a node-attribute-file for cytoscape to visualize the results:\cr

\code{buildCytoscapeNAFiles(model=ec, fileprefix="ecoli_NA", reactSets=rS, blocked=erg\$reactions\$blocked)}


}
\author{
Claus Jonathan Fritzemeier \email{clausjonathan.fritzemeier@uni-duesseldorf.de}
}
\references{
Bockmayr, Alexander ; Larhlimi, Abdelhalim: A New Approach to Flux Coupling Analysis of Metabolic Networks. \cr
Bockmayr, Alexander ; Larhlimi, Abdelhalim: Minimal Metabolic Behaviors and the Reversible Metabolic Space. \cr
Fritzemeier, Claus Jonathan: Flux Coupling in Biological Networks. 2010. -- Bachelor's thesis. \cr
Fukuda, Komei: cddlib Reference Manual. 2003. -- \cr URL http://www.cs.mcgill.ca/~fukuda/soft/cddlibman/cddlibman.html \cr
Gelius Dietrich, Gabriel: SyBiL -- Systems Biology Library. -- current project of bioinformatics at Heinrich Heine Universitaet Duesseldorf. \cr
Geyer, Charles: rcdd (C Double Description) package for R. \cr
}
\keyword{ package }
\seealso{
Package \code{rcdd} (\code{\link[rcdd]{scdd}}),
Package \code{SyBiL} (\code{\link[sybil]{readSBMLmod}}),
}
\examples{
data("Ec_core")
gv <- calcGeneratingVectorsFromModelorg(Ec_core, setObjectiveReactionToZero=TRUE)
res <- fcf(Ec_core, gv)
rS <- orderSymmetricReactionSets(res$A, sortSets=TRUE)
buildCytoscapeNAFiles(model=Ec_core, fileprefix="ecoli_NA",
						reactSets=rS, blocked=res$reactions$blocked)
}
